[Python-checkins] r51961 - in sandbox/branches/setuptools-0.6: setuptools.txt setuptools/command/bdist_rpm.py

phillip.eby python-checkins at python.org
Fri Sep 22 00:01:23 CEST 2006


Author: phillip.eby
Date: Fri Sep 22 00:01:22 2006
New Revision: 51961

Modified:
   sandbox/branches/setuptools-0.6/setuptools.txt
   sandbox/branches/setuptools-0.6/setuptools/command/bdist_rpm.py
Log:
Fix ``upload`` not uploading files built by ``bdist_rpm`` on Python 2.3 and
2.4.  (Backport from trunk)


Modified: sandbox/branches/setuptools-0.6/setuptools.txt
==============================================================================
--- sandbox/branches/setuptools-0.6/setuptools.txt	(original)
+++ sandbox/branches/setuptools-0.6/setuptools.txt	Fri Sep 22 00:01:22 2006
@@ -2563,6 +2563,10 @@
 Release Notes/Change History
 ----------------------------
 
+0.6c4
+ * Fix ``upload`` not uploading files built by ``bdist_rpm`` on Python 2.3 and
+   2.4.
+
 0.6c3
  * Fixed breakages caused by Subversion 1.4's new "working copy" format
 

Modified: sandbox/branches/setuptools-0.6/setuptools/command/bdist_rpm.py
==============================================================================
--- sandbox/branches/setuptools-0.6/setuptools/command/bdist_rpm.py	(original)
+++ sandbox/branches/setuptools-0.6/setuptools/command/bdist_rpm.py	Fri Sep 22 00:01:22 2006
@@ -1,8 +1,10 @@
 # This is just a kludge so that bdist_rpm doesn't guess wrong about the
 # distribution name and version, if the egg_info command is going to alter
 # them, and another kludge to allow you to build old-style non-egg RPMs
 
 from distutils.command.bdist_rpm import bdist_rpm as _bdist_rpm
+import sys
 
 class bdist_rpm(_bdist_rpm):
 
@@ -10,10 +12,33 @@
         _bdist_rpm.initialize_options(self)
         self.no_egg = None
 
+    if sys.version<"2.5":
+        # Track for uploading any .rpm file(s) moved to self.dist_dir
+        def move_file(self, src, dst, level=1):
+            _bdist_rpm.move_file(self, src, dst, level)
+            if dst==self.dist_dir and src.endswith('.rpm'):
+                getattr(self.distribution,'dist_files',[]).append(
+                    ('bdist_egg',
+                    src.endswith('.src.rpm') and 'any' or get_python_version(),
+                     os.path.join(dst, os.path.basename(src)))
+                )
+
     def run(self):
         self.run_command('egg_info')    # ensure distro name is up-to-date
         _bdist_rpm.run(self)
 
+
+
+
+
+
+
+
+
+
+
+
+
     def _make_spec_file(self):
         version = self.distribution.get_version()
         rpmversion = version.replace('-','_')
@@ -55,14 +80,3 @@
 
 
 
-
-
-
-
-
-
-
-
-
-
-
@@ -1,8 +1,10 @@
 # This is just a kludge so that bdist_rpm doesn't guess wrong about the
 # distribution name and version, if the egg_info command is going to alter
-# them, and another kludge to allow you to build old-style non-egg RPMs
+# them, another kludge to allow you to build old-style non-egg RPMs, and
+# finally, a kludge to track .rpm files for uploading when run on Python <2.5.
 
 from distutils.command.bdist_rpm import bdist_rpm as _bdist_rpm


More information about the Python-checkins mailing list